=begin ###################################################################################
   Copyright 2010 Christopher Nicholson-Sauls

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
=end #####################################################################################

##########################################################################################
#   Namespace
#
module Refuge

    ##################################################################################
    #   
    #
    LIBBASE             = 'refuge/'
    LIBBASE_COMMANDS    = LIBBASE + 'commands/'
    LIBBASE_NATIVE      = LIBBASE + 'native/'
    LIBBASE_UTILS       = LIBBASE + 'utils/'

    ##################################################################################
    #   
    #
    DEFAULT_COMMAND = 'help'

    ##################################################################################
    #   Standard exit code mappings.
    #
    EXIT_CODES = {
        :ok               => [ 0, '' ],
        :general          => [ 1, 'General error' ],
        
        :os_not_supported => [ 10, 'Your operating system is not yet supported' ],
        
        :native_not_impl  => [ 20, 'A native interface feature is not implemented' ],
        :cmd_not_impl     => [ 21, 'A command feature is not implemented' ],
    }

    ##################################################################################
    #   Everything after this is a function.
    #
    module_function
    
    ##################################################################################
    #   Loads a set of library scripts under a common base path.
    #
    def load_libs ( base, names )
        names.each do | elem |
            require base + elem
        end
    end

end # module Refuge

##########################################################################################
#   Load 'utils' libs.
#
Refuge::load_libs Refuge::LIBBASE_UTILS, [
    'array',
    'string',
    'symbol'
]

##########################################################################################
#   Load core libs.
#
Refuge::load_libs Refuge::LIBBASE, [
    'commands',
    'native',
    'options'
]
